#!/bin/sh
#set -x
#=======================================================================
# * Version: $Id: cron_hourly.src,v 1.5 2015/09/22 11:42:40 nroche Exp $
# * Project: MediaTex
# * Module : scripts
# *
# * This script is call by cron
#
# MediaTex is an Electronic Records Management System
# Copyright (C) 2014 2015 Nicolas Roche
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#=======================================================================

BINDIR=/usr/local/bin

$BINDIR/mediatex -swarning -ffile srv extract    
$BINDIR/mediatex -swarning -ffile srv notify

